// src/bun.ts
import { Database } from "bun:sqlite";
import { randomBytes } from "node:crypto";
import { CamelCasePlugin, Kysely } from "kysely";
import { BunSqliteDialect } from "kysely-bun-sqlite";
import { bun } from "plainjob";

// src/database.ts
import { join } from "node:path";
import consola from "consola";
import { Migrator, sql } from "kysely";
import {
  DEFAULT_NUMERIC_PARSER,
  DialectManager,
  generate
} from "kysely-codegen";

// src/env.ts
function test() {
  return process.env.NODE_ENV === "test";
}

// src/database.ts
function migrate(db) {
  return async (...fns) => {
    const migrations = {};
    for (const [idx, fn] of fns.entries()) {
      migrations[idx] = { up: fn };
    }
    const migrator = new Migrator({
      db,
      provider: {
        async getMigrations() {
          return migrations;
        }
      },
      allowUnorderedMigrations: true
    });
    const result = await migrator.migrateToLatest();
    consola.debug(result);
    consola.info("\u2713 migrations applied");
    const dialectManager = new DialectManager({
      numericParser: DEFAULT_NUMERIC_PARSER
    });
    if (!test()) {
      const dialect = dialectManager.getDialect("kysely-bun-sqlite");
      await generate({
        camelCase: true,
        db,
        dialect,
        print: false,
        typeOnlyImports: true,
        runtimeEnums: true,
        outFile: join(
          process.cwd(),
          "node_modules",
          "plainstack",
          "dist",
          "db.d.ts"
        )
      });
    }
    consola.info("\u2713 types generated");
    if (process.env.MIRGATE) {
      console.info("MIGRATE env var set, stopping process");
      process.exit(0);
    }
  };
}

// src/job.ts
import consola2 from "consola";
import { defineQueue, defineWorker } from "plainjob";
function queue(opts) {
  const logger = consola2;
  return defineQueue({ connection: opts.connection, logger });
}

// src/bun.ts
function bunSqlite() {
  const sqlite = new Database(test() ? ":memory:" : "data.db", {
    strict: true
  });
  const q = queue({
    connection: bun(sqlite)
  });
  const database = new Kysely({
    dialect: new BunSqliteDialect({
      database: sqlite
    }),
    plugins: [new CamelCasePlugin()]
  });
  const migrate2 = migrate(database);
  return { sqlite, database, migrate: migrate2, queue: q };
}
async function secret() {
  if (process.env.SECRET_KEY) return process.env.SECRET_KEY;
  const newSecret = randomBytes(16).toString("hex");
  const envFile = Bun.file(".env");
  if (!await envFile.exists()) {
    await Bun.write(".env", `SECRET_KEY="${newSecret}"`);
  } else {
    const envContent = await envFile.text();
    Bun.write(".env", `${envContent}
SECRET_KEY="${newSecret}"`);
  }
  return newSecret;
}
export {
  bunSqlite,
  secret
};
//# sourceMappingURL=bun.js.map